@@ -11,14 +11,14 @@
 
 package Minecraft::RCON;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01_02';
 
-use 5.010;
+use 5.008;
 use strict;
 use warnings;
 no warnings 'uninitialized';
 
-use Term::ANSIColor  3.01;
+use Term::ANSIColor  3.02;
 use IO::Socket       1.18;  # autoflush
 use Carp;
 
@@ -128,7 +128,7 @@ sub command {
     croak 'Not connected'    unless $s->connected;
 
     my $id = $s->_next_id;
-    my $nonce = 16 + int rand(2 ** 15 - 16); # Avoid 0..15
+    my $nonce = 16 + int rand(1 << 15 - 16); # Avoid 0..15
     $s->_send_encode(COMMAND, $id, $command);
     $s->_send_encode($nonce,  $id, 'nonce');
 
@@ -255,7 +255,7 @@ sub _recv_decode {
         $frags++;
     }
 
-    croak 'Packet too short. ' . length($_) . ' < 10' if 10 > length($_);
+    croak 'Packet too short. ' . length . ' < 10' if 10 > length;
     croak "Received packet missing terminator" unless s/\0\0$//;
 
     $size, unpack 'V!V(A*)';
@@ -271,7 +271,7 @@ Minecraft::RCON - RCON remote console communication with Minecraft servers
 
 =head1 VERSION
 
-Version 1.00
+Version 1.010_01
 
 =head1 SYNOPSIS
 
